﻿import os
import platform
from shutil import copyfile
import sys

demos = {
  "annotation",
  "associated_files",
  "async_load",
  "attachment",
  "barcode",
  "bitmap_transform",
  "bookmark",
  "compliance",
  "electronictable",
  "docinfo",
  "dwg2pdf",
  "fdf",
  "fillsign",
  "form",
  "form_combination",
  "form_recognition",
  "fulltextsearch",
  "graphics_objects",
  "html2pdf",
  "image2pdf",
  "layout_recognition",
  "ltv",
  "marked_content",
  "matrix",
  "ocr",
  "ofd",
  "office2pdf",
  "optimization",
  "output_preview",
  "pades",
  "page_labels",
  "page_organization",
  "paging_seal_signature",
  "pdf2image",
  "pdf2text",
  "pdfcompare",
  "pdfflatten",
  "pdfheaderfooter",
  "pdflayer",
  "pdfobjects",
  "pdfprint",
  "pdfredact",
  "pdfreflow",
  "pdfwrapper",
  "portfolio",
  "psi",
  "pdfcombination",
  "search",
  "searchreplace",
  "security",
  "signature",
  "taggedpdf",
  "text2pdf",
  "watermark",
  "xfa_form"
}

def copy_lib():
    arch = platform.architecture()
    cur_sys = platform.system()
    
    if arch[0] == "32bit" and cur_sys == "Windows":
        src_lib_path = "../../FoxitPDFSDKPython2/x86_vc15/_fsdk.pyd"
    elif arch[0] == "64bit" and cur_sys == "Windows":
        src_lib_path = "../../FoxitPDFSDKPython2/x64_vc15/_fsdk.pyd"
    elif arch[0] == "32bit" and cur_sys == "Linux":
        src_lib_path = "../../FoxitPDFSDKPython2/x86/_fsdk.so"
    elif arch[0] == "64bit" and cur_sys == "Linux":
        src_lib_path = "../../FoxitPDFSDKPython2/x64/_fsdk.so"
    else:
        src_lib_path = None
    
    if cur_sys == "Windows":
        dest_lib_path = "../../FoxitPDFSDKPython2/_fsdk.pyd"
    else:
        dest_lib_path = "../../FoxitPDFSDKPython2/_fsdk.so"

    if src_lib_path is not None:
        copyfile(src_lib_path, dest_lib_path)

def run_single_demo(demo):
    os.chdir(demo)
    democmd = 'python -u ' + demo + '.py'
    os.system(democmd)


def run_all_demos():
    if not os.path.exists('demo_log_py'):
        os.mkdir('demo_log_py')

    for demo in demos:
        if platform.system() == "Darwin" and (demo == "pdfprint" or demo == "office2pdf" or demo == "ocr" or demo == "ofd"):
            continue
        elif platform.system() == "Linux" and (demo == "pdfprint" or demo == "office2pdf" or demo == "ocr" or demo == "ofd"):
            continue
        if not os.path.exists(demo):
            continue
        os.chdir(demo)
        democmd = 'python -u ' + demo + '.py >> ../demo_log_py/' + demo + '.log 2>&1'
        os.system(democmd)
        print('demo ' + demo + ' finished !')
        os.chdir('../')

if __name__ == '__main__':
    major = sys.version_info.major
    minor = sys.version_info.minor
    if not (major == 2 and minor == 7) and not (major == 3 and minor > 5 and minor < 11):
        print("Run error: you need Python2.7 or Python3.6-3.10 to run this py.")
        sys.exit(0)
    if major == 2 and minor == 7:
        copy_lib()

    if len(sys.argv) > 1:
        run_single_demo(sys.argv[1])
    else:
        run_all_demos()